@@ -6,8 +6,8 @@
 #'
 #' @param x either a \code{[2 x n]} matrix with measurements and their
 #'     standard errors, or an object of class \code{fissiontracks},
-#'     \code{UPb}, \code{ArAr}, \code{ReOs}, \code{SmNd}, \code{RbSr}
-#'     or \code{UThHe}
+#'     \code{UPb}, \code{ArAr}, \code{ReOs}, \code{SmNd}, \code{RbSr},
+#'     \code{LuHf} or \code{UThHe}
 #' @param k the number of discrete age components to be
 #'     sought. Setting this parameter to \code{'auto'} automatically
 #'     selects the optimal number of components (up to a maximum of 5)
@@ -100,12 +100,13 @@ peakfit.UPb <- function(x,k=1,type=4,cutoff.76=1100,
                    cutoff.disc=cutoff.disc,exterr=exterr,
                    sigdig=sigdig,log=log,...)
 }
-#' @param i2i `isochron to intercept': calculates the initial (aka `inherited',
+#' @param i2i
+#'     `isochron to intercept': calculates the initial (aka `inherited',
 #'     `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
-#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd or
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os ratio from an isochron
-#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}
+#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
+#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
+#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
+#'     uses the default values stored in \code{settings('iratio',...)}
 #' @rdname peakfit
 #' @export
 peakfit.ArAr <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=FALSE,...){
@@ -128,6 +129,11 @@ peakfit.RbSr <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
 }
 #' @rdname peakfit
 #' @export
+peakfit.LuHf <- function(x,k=1,exterr=TRUE,sigdig=2,log=TRUE,i2i=TRUE,...){
+    peakfit.helper(x,k=k,exterr=exterr,sigdig=sigdig,log=log,i2i=i2i,...)
+}
+#' @rdname peakfit
+#' @export
 peakfit.UThHe <- function(x,k=1,sigdig=2,log=TRUE,...){
     peakfit.helper(x,k=k,sigdig=sigdig,log=log,...)
 }
@@ -164,6 +170,8 @@ ages2peaks <- function(x,k=1,type=4,cutoff.76=1100,
         tt <- SmNd.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'RbSr')){
         tt <- RbSr.age(x,exterr=FALSE,i2i=i2i)
+    } else if (hasClass(x,'LuHf')){
+        tt <- LuHf.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'fissiontracks')){
         tt <- fissiontrack.age(x,exterr=FALSE)
     }
