@@ -10,7 +10,8 @@
 #' OR
 #'
 #' and object of class \code{fissiontracks}, \code{UThHe},
-#' \code{ArAr}, \code{ReOs}, \code{SmNd}, \code{RbSr} or \code{UPb}
+#' \code{ArAr}, \code{ReOs}, \code{SmNd}, \code{RbSr}, \code{LuHf} or
+#' \code{UPb}
 #' @param from minimum age limit of the radial scale
 #' @param to maximum age limit of the radial scale
 #' @param t0 central value
@@ -48,11 +49,12 @@ radialplot <- function(x,...){ UseMethod("radialplot",x) }
 #' @export
 radialplot.default <- function(x,from=NA,to=NA,t0=NA,transformation='log',
                                sigdig=2,show.numbers=FALSE,pch=21,
-                               bg='white',k=0,markers=NULL,...){
+                               bg='white',title=TRUE,k=0,markers=NULL,...){
     peaks <- peakfit(x,k=k,sigdig=sigdig)
     markers <- c(markers,peaks$peaks)
     X <- x2zs(x,t0=t0,from=from,to=to,transformation=transformation)
     radial.plot(X,show.numbers=show.numbers,pch=pch,bg=bg,markers=markers,...)
+    if (title) title(radial.title(central(x),sigdig=sigdig))
     if (!is.null(peaks$legend))
         graphics::legend('bottomleft',legend=peaks$legend,bty='n')
 }
@@ -109,10 +111,10 @@ radialplot.UPb <- function(x,from=NA,to=NA,t0=NA,
 }
 #' @param i2i `isochron to intercept': calculates the initial (aka `inherited',
 #'     `excess', or `common') \eqn{^{40}}Ar/\eqn{^{36}}Ar,
-#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd or
-#'     \eqn{^{187}}Os/\eqn{^{188}}Os ratio from an isochron
-#'     fit. Setting \code{i2i} to \code{FALSE} uses the default values
-#'     stored in \code{settings('iratio',...)}
+#'     \eqn{^{87}}Sr/\eqn{^{86}}Sr, \eqn{^{143}}Nd/\eqn{^{144}}Nd,
+#'     \eqn{^{187}}Os/\eqn{^{188}}Os or \eqn{^{176}}Hf/\eqn{^{177}}Hf
+#'     ratio from an isochron fit. Setting \code{i2i} to \code{FALSE}
+#'     uses the default values stored in \code{settings('iratio',...)}
 #' @rdname radialplot
 #' @export
 radialplot.ArAr <- function(x,from=NA,to=NA,t0=NA,
@@ -167,6 +169,17 @@ radialplot.RbSr <- function(x,from=NA,to=NA,t0=NA,
                       show.numbers=show.numbers,pch=pch,bg=bg,
                       markers=markers,k=k,exterr=exterr,i2i=i2i,...)
 }
+#' @rdname radialplot
+#' @export
+radialplot.LuHf <- function(x,from=NA,to=NA,t0=NA,
+                            transformation='log',show.numbers=FALSE,
+                            pch=21,bg='white',markers=NULL,k=0,
+                            exterr=TRUE,i2i=TRUE,...){
+    radialplot.helper(x,from=from,to=to,t0=t0,
+                      transformation=transformation,
+                      show.numbers=show.numbers,pch=pch,bg=bg,
+                      markers=markers,k=k,exterr=exterr,i2i=i2i,...)
+}
 radialplot.helper <- function(x,from=NA,to=NA,t0=NA,
                              transformation='log',type=4,
                              cutoff.76=1100, cutoff.disc=c(-15,5),
@@ -200,6 +213,8 @@ age2radial <- function(x,from=NA,to=NA,t0=NA,transformation='log',
         tt <- SmNd.age(x,exterr=FALSE,i2i=i2i)
     } else if (hasClass(x,'RbSr')){
         tt <- RbSr.age(x,exterr=FALSE,i2i=i2i)
+    } else if (hasClass(x,'LuHf')){
+        tt <- LuHf.age(x,exterr=FALSE,i2i=i2i)
     }
     radialplot.default(tt,from=from,to=to,t0=t0,
                        transformation=transformation,
